Learn R Programming

hydroApps (version 0.1-1)

pBurrXII: The Extended Burr type XII distribution

Description

Density, distribution function and quantile function for the Extended (three-parameter) Burr type XII with scale parameter lambda and shape parameters k and c.

Usage

pBurrXII(x, lambda, k, c)
	dBurrXII(x, lambda, k, c)
	qBurrXII(p, lambda, k, c)

Arguments

x
vector of quantiles.
p
vector of probabilities.
lambda, k, c
respectively the scale parameter and the two shape parameters.

Value

  • dBurrXII gives the density, pBurrXII gives the distribution function and qBurrXII gives the quantile function. The length of the result is determined by the length of x or p vectors.

Details

The cumulative function of the extended Burr XII distribution reads: $$P(x) = 1-\left(1-k \left(\frac{x}{\lambda}\right)^c\right)^{1/k} \quad k \neq 0$$ $$P(x) = 1 - \exp \left[ -\left(\frac{x}{\lambda}\right)^c\right] \quad k = 0$$ where $x$ is the quantile, $P$ is the non-exceedance probability, $\lambda$ is the scale parameter and $k$ and $c$ are the shape parameters.

The range of the distribution is $0 \le x \le \infty$ for $k \le 0$ and $0 \le x \le \lambda k^{-1/c}$ otherwise.

References

D. Ganora and F. Laio. Hydrological applications of the Burr distribution: a practical method for parameter estimation. Submitted to Journal of Hydrologic Engineering (ASCE). Z. Hao and V.P. Singh. Entropy-based parameter estimation for extended Burr XII distribution. Stoch. Environ. Res. Risk. Assess. (2009) 23:1113-1122

See Also

lmomBurrXII, parBurrXII.approx