Learn R Programming

hydroApps (version 0.1-1)

parBurrXII.approx: Parameters of the Extended Burr type XII distribution

Description

Compute the parameters of the Extended Burr XII given the L-moments with some approximated functions.

Usage

parBurrXII.approx(L1, tau, tau3) tau3BurrXII.WeibullBound(tau) tau3BurrXII.ParetoBound(tau)

Arguments

L1
the mean of the distribution.
tau
the L-CV of the distribution.
tau3
the L-skewness of the distribution.

Value

parBurrXII.approx provides a vector of three elements which are the parameters of the distribution. tau3BurrXII.WeibullBound provide the minimum value of $\tau_3$ compatible with tau (corresponding to the lower bound in the $\tau$-$\tau_3$ space, i.e. when $k=0$). tau3BurrXII.paretoBound provide the maximum value of $tau_3$ compatible with tau (corresponding to the upper bound in the $\tau$-$\tau_3$ space, i.e. when $k$ tends to $\infty$)

Details

parBurrXII.approx computes the shape parameters using the approximated equations in Ganora and Laio (2014). Note that the approximated equations are valid only for $k \le 0$ (distribution without upper bound). Please refer to Ganora and Laio (2014) for details about the equations.

tau3BurrXII.WeibullBound and tau3BurrXII.ParetoBound are mostly used as internal functions, but can be useful for static plots and data interpretation. They represents the upper and lower bound of the distribution domain over the $\tau$-$tau_3$ space.

References

D. Ganora and F. Laio. Hydrological applications of the Burr distribution: a practical method for parameter estimation. Submitted to Journal of Hydrologic Engineering (ASCE). Z. Hao and V.P. Singh. Entropy-based parameter estimation for extended Burr XII distribution. Stoch. Environ. Res. Risk. Assess. (2009) 23:1113-1122

See Also

pBurrXII, dBurrXII, qBurrXII, lmomBurrXII

Examples

Run this code
## compute parameters from L-moments
parburr <- parBurrXII.approx(L1=2, tau=0.45, tau3=0.51)
parburr 

## Not run: 
# ## plot the validity domain in the tau-tau3 space
# tau = seq(0, 1, by=0.02)
# plot(tau, tau3BurrXII.WeibullBound(tau), type="l", lwd=2, ylim=c(-.2, 1))
# lines(tau, tau3BurrXII.ParetoBound(tau), lwd=2)
# ## End(Not run)

Run the code above in your browser using DataLab